function [ ] = arm_do_path( COM, path )
%ARM_DO_PATH Does the path
%   Pass in COM and path array (in seconds and inches)
%   Returns nothing
%   Crunches math on the path to prepare it for the pic
%   Sends the GOTO command to move the arm to the start position
%   Sends the path
%   Sends the run command
%   ---
%   Sam Bobb,  Daniel Cornew,  Ryan Deeter
%	Two degree of freedom arm
%	High speed motor control for 2 motors
%	Code version 3
%	March 18, 2010
%   ---

% pull in constants
arm_constants

% calculate length of path
[pathRows, pathCols] = size(path);
numPathPoints = pathRows;

% separate path into it's parts: t, x, and y
t = path(:,1);
x = path(:,2);
y = path(:,3);

% convert to theta1 and theta2
[theta1, theta2] = arm_xy_to_thetas(x, y);

% assemble into path for PIC and convert to time ticks and encoder counds
pathPIC = [ t/tick, theta1*countsPerRev/360, theta2*countsPerRev/360 ];

% reshape to the long vector for the serial sending
pathPICVector = reshape(pathPIC', 1, pathRows*pathCols);

disp('sending path vector')
fwrite(COM, [C_SET_PATH numPathPoints pathPICVector], 'int16');
pause(1);
disp('done')

arm_run(COM);

end

