function [ DATA ] = arm_get_log( COM )
%ARM_GET_LOG Gets data from the PIC
%   Pass in COM
%   Returns the data
%   ---
%   Sam Bobb,  Daniel Cornew,  Ryan Deeter
%	Two degree of freedom arm
%	High speed motor control for 2 motors
%	Code version 3
%	March 18, 2010
%   ---

% pull in constants
arm_constants

disp('ask for log')
fwrite(COM, C_SEND_LOG, 'int16');
pause(MINPAUSE);
% -----------------

%there's usually some garbage at the beginning (like the echoed p 
%character command and line  breaks); this reads lines in until we find 
%the start line
[text,COUNT,MSG] = fscanf(COM, '%s');
if(~isempty(MSG))
    disp('serial problem')
    return
end
while isempty(strfind(text, 'START'))
    [text,COUNT,MSG] = fscanf(COM, '%s');
    if(~isempty(MSG))
        disp('serial problem')
        return
    end
end


% read number of rows
[rowstext,COUNT,MSG] = fscanf(COM, '%s');
if(~isempty(MSG))
    disp('serial problem')
    return
end
pat = 'ROWS=';
split = regexp(rowstext, pat, 'split');
rows = str2double(split(2));

DATA = zeros(rows,log_columns);

%generate the fscanf format argument
%repeate the formatchar character for the number of columns
formatchar = '%d';
serialpat = '';

%establishing fscanf format
for j = 1:log_columns
    serialpat = [serialpat ' ' formatchar];
end
    
%reads serial data and puts it into DATA
for j = 1:rows
    [DATA(j, :),COUNT,MSG] = fscanf(COM, serialpat, [log_columns 1]);
    %disp(COM.BytesAvailable)
    if(~isempty(MSG))
        disp('serial problem')
        return
    end
end

%reads last line
[last,COUNT,MSG] = fscanf(COM, '%s');
if(~isempty(MSG))
    disp('serial problem')
    return
end

%verifies that last line read is the last line
if strcmp(last,'END')
    disp('Success')
else
    disp('Problem')
end

% -----------------


end

