function [ theta1, theta2 ] = arm_xy_to_thetas( x, y )
%ARM_XY_TO_THETAS Uses inversion kinematics to give angles for position
%   Pass in x and y
%   Returns theta1 and theta2 (in degrees)
%   ---
%   Sam Bobb,  Daniel Cornew,  Ryan Deeter
%	Two degree of freedom arm
%	High speed motor control for 2 motors
%	Code version 3
%	March 18, 2010
%   ---

% pull in constants
arm_constants

% calculate the theta path      
c2 = (x.^2 + y.^2 - L1.^2 - L2.^2) / (2 * L1 * L2);
s2 = sqrt(1 - c2.^2);
psi = acos((x.^2 + y.^2 - L1^2 - L2^2) / (2 * L1 * L2));
alpha = asin((y .* (L1 + L2 .* c2) - x .* L2 .* s2) ./ (x.^2 + y.^2));

% convert to degrees
theta1 = rad2deg(alpha);
theta2 = rad2deg(alpha+psi);

end

